[llvm-commits] CVS: llvm/utils/NightlyTest.pl

Chris Lattner lattner at cs.uiuc.edu
Mon Jun 12 12:03:29 PDT 2006



Changes in directory llvm/utils:

NightlyTest.pl updated: 1.108 -> 1.109
---
Log message:

Add a new -compileflags options, remove old externals location specifiers.
People should just use -with-externals.


---
Diffs of the changes:  (+12 -25)

 NightlyTest.pl |   37 ++++++++++++-------------------------
 1 files changed, 12 insertions(+), 25 deletions(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.108 llvm/utils/NightlyTest.pl:1.109
--- llvm/utils/NightlyTest.pl:1.108	Wed Jun  7 00:28:07 2006
+++ llvm/utils/NightlyTest.pl	Mon Jun 12 14:03:17 2006
@@ -17,9 +17,6 @@
 #                   -norunningtests.
 #  -norunningtests  Do not run the Olden benchmark suite with
 #                   LARGE_PROBLEM_SIZE enabled.
-#  -noexternals     Do not run the external tests (for cases where povray
-#                   or SPEC are not installed)
-#  -with-externals  Specify a directory where the external tests are located.
 #  -nodejagnu       Do not run feature or regression tests
 #  -parallel        Run two parallel jobs with GNU Make.
 #  -release         Build an LLVM Release version
@@ -43,14 +40,15 @@
 #                   override the default.
 #  -ldflags         Next argument specifies that linker options that override
 #                   the default.
 #  -extraflags      Next argument specifies extra options that are passed to
 #                   compile the tests.
 #
 #  ---------------- Options to configure llvm-test ----------------------------
-#  -spec2000path    Path to the benchspec directory in the SPEC 2000 distro
-#  -spec95path      Path to the benchspec directory in the SPEC 95 distro.
-#  -povraypath      Path to the povray sources
-#  -namdpath        Path to the namd sources
+#  -extraflags      Next argument specifies extra options that are passed to
+#                   compile the tests.
+#  -noexternals     Do not run the external tests (for cases where povray
+#                   or SPEC are not installed)
+#  -with-externals  Specify a directory where the external tests are located.
 #
 # CVSROOT is the CVS repository from which the tree will be checked out,
 #  specified either in the full :method:user at host:/dir syntax, or
@@ -100,8 +98,6 @@
 my $NICE = "";
 my $NODEJAGNU = 0;
 
-my $LLVMTESTCONFIGARGS = "";
-
 sub ReadFile {
   if (open (FILE, $_[0])) {
     undef $/;
@@ -334,23 +330,14 @@
   if (/^-ldflags/)         {
     $MAKEOPTS = "$MAKEOPTS LD.Flags=\'$ARGV[0]\'"; shift; next;
   }
-  if (/^-extraflags/)         {
+  if (/^-compileflags/)    {
+    $MAKEOPTS = "$MAKEOPTS $ARGV[0]"; shift; next;
+  }
+  if (/^-extraflags/)      {
     $PROGTESTOPTS .= " EXTRA_FLAGS=\'$ARGV[0]\'"; shift; next;
   }
   if (/^-noexternals$/)    { $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)      { $NODEJAGNU = 1; next; }
-  if (/^-spec2000path$/)   {
-    $LLVMTESTCONFIGARGS .= " --enable-spec2000=$ARGV[0]"; shift; next;
-  }
-  if (/^-spec95path$/)     {
-    $LLVMTESTCONFIGARGS .= " --enable-spec95=$ARGV[0]"; shift; next;
-  }
-  if (/^-povraypath$/)     {
-    $LLVMTESTCONFIGARGS .= " --enable-povray=$ARGV[0]"; shift; next;
-  }
-  if (/^-namdpath$/)       {
-    $LLVMTESTCONFIGARGS .= " --enable-namd=$ARGV[0]"; shift; next;
-  }
   print "Unknown option: $_ : ignoring!\n";
 }
 
@@ -462,7 +449,7 @@
 #
 if (!$NOCHECKOUT) {
   if ( $VERBOSE ) { print "CONFIGURE STAGE\n"; }
-  my $EXTRAFLAGS = "--enable-spec --with-objroot=.$LLVMTESTCONFIGARGS";
+  my $EXTRAFLAGS = "--enable-spec --with-objroot=.";
   system "(time -p $NICE ./configure $CONFIGUREARGS $EXTRAFLAGS) > $BuildLog 2>&1";
 
   if ( $VERBOSE ) { print "BUILD STAGE\n"; }
@@ -43,14 +40,15 @@
 #  -ldflags         Next argument specifies that linker options that override
 #                   the default.
-#  -extraflags      Next argument specifies extra options that are passed to
-#                   compile the tests.
+#  -compileflags    Next argument specifies extra options passed to make when
+#                   building LLVM.
 #
 #  ---------------- Options to configure llvm-test ----------------------------






More information about the llvm-commits mailing list